@@ -1,3 +1,4 @@
+
 # get 74
 # Sam Robson
 
@@ -417,7 +418,7 @@ def Charges(text: str):
     cnum = CaseNumber(text)
     rc = re.findall(r'(\d{3}\s{1}.{1,1000}?.{3}-.{3}-.{3}.{10,75})', text, re.MULTILINE)
     unclean = pd.DataFrame({'Raw':rc})
-    unclean['FailTimeTest'] = unclean['Raw'].map(lambda x: bool(re.search(r'([0-9]{1}\:[0-9]{2})', x)))
+    unclean['FailTimeTest'] = unclean['Raw'].map(lambda x: bool(re.search(r'([0-9]{1}\:{1}[0-9]{2})', x)))
     unclean['FailNumTest'] = unclean['Raw'].map(lambda x: False if bool(re.search(r'([0-9]{3}\s{1}.{4}\s{1})',x)) else True)
     unclean['Fail'] = unclean.index.map(lambda x: unclean['FailTimeTest'][x] == True or unclean['FailNumTest'][x]== True)
     passed = pd.Series(unclean[unclean['Fail']==False]['Raw'].dropna().explode().tolist())
@@ -430,7 +431,7 @@ def Charges(text: str):
     c = passed.dropna().tolist()
     cind = range(0, len(c))
     charges = pd.DataFrame({ 'Charges': c,'parentheses':'','decimals':''},index=cind)
-    charges['Charges'] = charges['Charges'].map(lambda x: re.sub(r'(©.+)','',x,re.MULTILINE))
+    charges['Charges'] = charges['Charges'].map(lambda x: re.sub(r'(\$|\:|©.+)','',x,re.MULTILINE))
     charges['CaseNumber'] = charges.index.map(lambda x: cnum)
     split_charges = charges['Charges'].map(lambda x: x.split(" "))
     charges['Num'] = split_charges.map(lambda x: x[0].strip())
