@@ -1,3 +1,4 @@
+
 # parse 74
 # Sam Robson
 
@@ -18,9 +19,9 @@ import time
 import warnings
 import click
 import inspect
-from alacorder import get #
-from alacorder import write #
-from alacorder import config #
+from alacorder import get 
+from alacorder import write 
+from alacorder import config 
 from alacorder import logs
 import PyPDF2
 from io import StringIO
@@ -71,8 +72,10 @@ def fees(conf):
     fees = pd.DataFrame({'CaseNumber': '', 
         'Code': '', 'Payor': '', 'AmtDue': '', 
         'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
-
-    batches = config.batcher(conf)
+    if not conf['NO_BATCH']:
+        batches = config.batcher(conf)
+    else:
+        batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
     batchcount = len(batches)
     with click.progressbar(batches) as bar:
@@ -96,9 +99,12 @@ def fees(conf):
             feesheet = feesheet.dropna() # drop empty 
             fees =fees.dropna()
             feesheet = feesheet.tolist() # convert to list -> [df, df, df]
-            feesheet = pd.concat(feesheet,axis=0,ignore_index=True) # add all dfs in batch -> df
+            try:
+                feesheet = pd.concat(feesheet,axis=0,ignore_index=True) # add all dfs in batch -> df
+            except ValueError:
+                pass
             fees = fees.append(feesheet, ignore_index=True) 
-            fees = fees[['CaseNumber', 'Total', 'FeeStatus', 'AdminFee', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
+            fees = fees[['CaseNumber', 'FeeStatus', 'AdminFee', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
             fees.fillna('',inplace=True)
             fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
             fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
@@ -129,7 +135,10 @@ def charges(conf):
     if warn == False:
         warnings.filterwarnings("ignore")
 
-    batches = config.batcher(conf)
+    if not conf['NO_BATCH']:
+        batches = config.batcher(conf)
+    else:
+        batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
 
     start_time = time.time()
@@ -173,7 +182,6 @@ def charges(conf):
     return charges
 def cases(conf):
     """
-    ~~the whole shebang~~
     Return [cases, fees, charges] tables as List of DataFrames from batch
     See API docs for table specific outputs
     """
@@ -199,7 +207,10 @@ def cases(conf):
     fees = pd.DataFrame({'CaseNumber': '', 'FeeStatus': '','AdminFee': '', 'Code': '', 'Payor': '', 'AmtDue': '', 'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
     charges = pd.DataFrame({'CaseNumber': '', 'Num': '', 'Code': '', 'Felony': '', 'Conviction': '', 'CERV': '', 'Pardon': '', 'Permanent': '', 'Disposition': '', 'CourtActionDate': '', 'CourtAction': '', 'Cite': '', 'TypeDescription': '', 'Category': '', 'Description': ''},index=[0]) 
     arch = pd.DataFrame({'Path':'','AllPagesText':'','Timestamp':''},index=[0])
-    batches = config.batcher(conf)
+    if not conf['NO_BATCH']:
+        batches = config.batcher(conf)
+    else:
+        batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
     if warn == False:
         warnings.filterwarnings("ignore")
@@ -242,7 +253,7 @@ def cases(conf):
             b['TotalAmtDue'] = b['FeeOutputs'].map(lambda x: x[0])
             b['TotalBalance'] = b['FeeOutputs'].map(lambda x: x[1])
             b['PaymentToRestore'] = b['AllPagesText'].map(lambda x: get.PaymentToRestore(x))
-            b['PaymentToRestore'][b.CERVConvictionCount == 0] = pd.NaT
+            b['PaymentToRestore'][b['CERVConvictionCount'] == 0] = pd.NaT
             b['FeeCodesOwed'] = b['FeeOutputs'].map(lambda x: x[3])
             b['FeeCodes'] = b['FeeOutputs'].map(lambda x: x[4])
             b['FeeSheet'] = b['FeeOutputs'].map(lambda x: x[5])
@@ -321,8 +332,8 @@ def cases(conf):
             cases.fillna('',inplace=True)
             newcases = [cases, b]
             cases = cases.append(newcases, ignore_index=True)
-            charges = charges[['CaseNumber', 'Num', 'Code', 'Description', 'Cite', 'CourtAction', 'CourtActionDate', 'Category', 'TypeDescription', 'Disposition', 'Permanent', 'Pardon', 'CERV','Conviction']]
-            fees = fees[['CaseNumber', 'FeeStatus', 'AdminFee','Total', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
+            # charges = charges[['CaseNumber', 'Num', 'Code', 'Description', 'Cite', 'CourtAction', 'CourtActionDate', 'Category', 'TypeDescription', 'Disposition', 'Permanent', 'Pardon', 'CERV','Conviction']]
+            # fees = fees[['CaseNumber', 'FeeStatus', 'AdminFee','Total', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
             
             # write     
             if appendtable:
@@ -349,43 +360,48 @@ def cases(conf):
             if no_write == False and temp_no_write_tab == False and (i % 5 == 0 or i == len(batches) - 1):
                 if out_ext == ".xls":
                     try:
-                        with pd.ExcelWriter(path_out,engine="xlsxwriter") as writer:
+                        with pd.ExcelWriter(path_out,engine="openpyxl") as writer:
                             cases.to_excel(writer, sheet_name="cases")
                             fees.to_excel(writer, sheet_name="fees")
                             charges.to_excel(writer, sheet_name="charges")
-                    except (ImportError, IndexError, ValueError):
-                        with pd.ExcelWriter(path_out,engine="openpyxl") as writer:
+                    except (ImportError, IndexError, ValueError, ModuleNotFoundError, FileNotFoundError):
+                        click.echo(f"openpyxl engine failed! Trying xlsxwriter...")
+                        with pd.ExcelWriter(path_out,engine="xlsxwriter") as writer:
                             cases.to_excel(writer, sheet_name="cases")
                             fees.to_excel(writer, sheet_name="fees")
                             charges.to_excel(writer, sheet_name="charges")
                 elif out_ext == ".xlsx":
                     try:
-                        with pd.ExcelWriter(path_out,engine="xlsxwriter") as writer:
+                        with pd.ExcelWriter(path_out,engine="openpyxl") as writer:
                             cases.to_excel(writer, sheet_name="cases")
                             fees.to_excel(writer, sheet_name="fees")
                             charges.to_excel(writer, sheet_name="charges")
-                    except (ImportError, IndexError, ValueError):
+                    except (ImportError, IndexError, ValueError, ModuleNotFoundError, FileNotFoundError):
                         try:
-                            with pd.ExcelWriter(path_out,engine="openpyxl") as writer:
+                            if warn:
+                                click.echo(f"openpyxl engine failed! Trying xlsxwriter...")
+                            with pd.ExcelWriter(path_out,engine="xlsxwriter") as writer:
                                 cases.to_excel(writer, sheet_name="cases")
                                 fees.to_excel(writer, sheet_name="fees")
                                 charges.to_excel(writer, sheet_name="charges")
-                        except (ImportError, FileNotFoundError, IndexError, ValueError):
+                        except (ImportError, FileNotFoundError, IndexError, ValueError, ModuleNotFoundError):
                             try:
                                 try:
                                     if not appendtable:
                                         os.remove(path_out)
                                 except:
                                     pass
-                                cases.to_csv(path_out + "-cases.csv",escapechar='\\')
-                                fees.to_csv(path_out + "-fees.csv",escapechar='\\')
-                                charges.to_csv(path_out + "-charges.csv",escapechar='\\')
-                                logs.console(conf, f"(Batch {i+1}) - WARNING: Exported to CSV due to XLSX engine failure")
+                                cases.to_json(os.path.splitext(path_out)[0] + "-cases.json.zip", orient='table')
+                                fees.to_json(os.path.splitext(path_out)[0] + "-fees.json.zip",orient='table')
+                                charges.to_json(os.path.splitext(path_out)[0] + "-charges.json.zip",orient='table')
+                                click.echo("Fallback export to " + os.path.splitext(path_out)[0] + "-cases.json.zip due to Excel engine failure, usually caused by exceeding max row limit for .xls/.xlsx files!")
+
+                                # ADD LOG
                             except (ImportError, FileNotFoundError, IndexError, ValueError):
-                                click.echo("Failed to export to CSV...")
-                                pass
+                                click.echo("Failed to export!")
+                            
                 elif out_ext == ".json":
-                    cases.to_json(path_out)
+                    cases.to_json(path_out,orient='table')
                 elif out_ext == ".csv":
                     cases.to_csv(path_out,escapechar='\\')
                 elif out_ext == ".md":
@@ -421,12 +437,16 @@ def caseinfo(conf):
     dedupe = conf['DEDUPE']
     table = conf['TABLE']
     dedupe = conf['DEDUPE']
-    path_out = conf['OUTPUT_PATH'] if config.MAKE != "archive" else ''
-    archive_out = conf['OUTPUT_PATH'] if config.MAKE == "archive" else ''
+    path_out = conf['OUTPUT_PATH'] if conf.MAKE != "archive" else ''
+    archive_out = conf['OUTPUT_PATH'] if conf.MAKE == "archive" else ''
+    from_archive = True if conf['IS_FULL_TEXT'] else False
 
     cases = pd.DataFrame()
 
-    batches = config.batcher(conf)
+    if not conf['NO_BATCH']:
+        batches = config.batcher(conf)
+    else:
+        batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
     
     
@@ -456,7 +476,7 @@ def caseinfo(conf):
             b['TotalBalance'] = b['Totals'].map(lambda x: x[3])
             b['TotalAmtHold'] = b['Totals'].map(lambda x: x[4])
             b['PaymentToRestore'] = b['AllPagesText'].map(lambda x: get.PaymentToRestore(x))
-            b['PaymentToRestore'][b.CERVConvictionCount == 0] = pd.NaT
+            b['PaymentToRestore'][b['CERVConvictionCount'] == 0] = pd.NaT
             b['ConvictionCodes'] = b['AllPagesText'].map(lambda x: get.ConvictionCodes(x))
             b['ChargeCodes'] = b['AllPagesText'].map(lambda x: get.ChargeCodes(x))
             b['FeeCodes'] = b['AllPagesText'].map(lambda x: get.FeeCodes(x))
@@ -502,13 +522,16 @@ def map(conf, *args):
     dedupe = conf['DEDUPE']
     table = conf['TABLE']
     dedupe = conf['DEDUPE']
-    path_out = conf['OUTPUT_PATH'] if config.MAKE != "archive" else ''
-    archive_out = conf['OUTPUT_PATH'] if config.MAKE == "archive" else ''
+    path_out = conf['OUTPUT_PATH'] if conf.MAKE != "archive" else ''
+    archive_out = conf['OUTPUT_PATH'] if conf.MAKE == "archive" else ''
     from_archive = True if conf['IS_FULL_TEXT']==True else False
 
     if warn == False:
         warnings.filterwarnings("ignore")
-    batches = config.batcher(conf)
+    if not conf['NO_BATCH']:
+        batches = config.batcher(conf)
+    else:
+        batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
 
     start_time = time.time()
