@@ -21,7 +21,6 @@ import inspect
 import alacorder as alac
 from alacorder import get 
 from alacorder import parse 
-from alacorder import write 
 from alacorder import config 
 from alacorder import logs
 import PyPDF2
@@ -72,43 +71,44 @@ def now(conf, outputs, archive=False):
     if out_ext == ".xls":
         try:
             with pd.ExcelWriter(path_out) as writer:
-                outputs.to_excel(writer, sheet_name="output-table")
-        except ValueError:
+                outputs.to_excel(writer, sheet_name="output-table",engine="openpyxl")
+        except (ImportError, IndexError, ValueError, ModuleNotFoundError, FileNotFoundError):
             try:
                 with pd.ExcelWriter(path_out,engine="xlwt") as writer:
                     outputs.to_excel(writer, sheet_name="output-table")
-            except ValueError:
+            except (ImportError, IndexError, ValueError, ModuleNotFoundError, FileNotFoundError):
                 try:
                     if not appendTable:
                         os.remove(path_out)
                 except:
                     pass
-                outputs.to_csv(path_out,escapechar='\\')
+                outputs.to_json(os.path.splitext(path_out)[0] + "-cases.json.zip", orient='table')
                 if warn or print_log:
-                    click.echo("Exported to CSV due to XLSX engine failure")
+                    click.echo(f"Fallback export to {os.path.splitext(path_out)[0] + "-cases.json.zip"} due to Excel engine failure, usually caused by exceeding max row limit for .xls/.xlsx files!")
+
     if out_ext == ".xlsx":
         try:
             with pd.ExcelWriter(path_out) as writer:
-                outputs.to_excel(writer, sheet_name="output-table", engine="xlsxwriter")
-        except ValueError:
+                outputs.to_excel(writer, sheet_name="output-table", engine="openpyxl")
+        except (ImportError, IndexError, ValueError, ModuleNotFoundError, FileNotFoundError):
             try:
                 with pd.ExcelWriter(path_out[0:-1]) as writer:
-                    outputs.to_excel(writer, sheet_name="output-table")
-            except ValueError:
+                    outputs.to_excel(writer, sheet_name="output-table", engine="xlsxwriter")
+            except (ImportError, IndexError, ValueError, ModuleNotFoundError, FileNotFoundError):
                 try:
                     if not appendTable:
                         os.remove(path_out)
                 except:
                     pass
-                outputs.to_csv(path_out+".csv",escapechar='\\')
+                outputs.to_json(os.path.splitext(path_out)[0] + "-cases.json.zip", orient='table')
                 if warn or print_log:
-                    click.echo("Exported to CSV due to XLSX engine failure")
+                    click.echo(f"Fallback export to {os.path.splitext(path_out)[0] + "-cases.json.zip"} due to Excel engine failure, usually caused by exceeding max row limit for .xls/.xlsx files!")
     elif out_ext == ".pkl":
         outputs.to_pickle(path_out+".xz",compression="xz")
     elif out_ext == ".xz":
         outputs.to_pickle(path_out,compression="xz")
     elif out_ext == ".json":
-        outputs.to_json(path_out)
+        outputs.to_json(path_out,orient='table')
     elif out_ext == ".csv":
         outputs.to_csv(path_out,escapechar='\\')
     elif out_ext == ".txt":
@@ -116,8 +116,7 @@ def now(conf, outputs, archive=False):
     elif out_ext == ".dta":
         outputs.to_stata(path_out)
     else:
-        if warn:
-            click.echo("Warning: Failed to export!")
+        pass
     return outputs 
 
 def archive(conf): 
@@ -136,15 +135,15 @@ def archive(conf):
     dedupe = conf['DEDUPE']
     table = conf['TABLE']
     dedupe = conf['DEDUPE']
-    OLD_ARCHIVE = conf['OLD_ARCHIVE']
+    old_archive = conf['OLD_ARCHIVE']
     append = conf['APPEND']
     from_archive = True if conf['IS_FULL_TEXT']==True else False
 
     start_time = time.time()
     if warn == False:
         warnings.filterwarnings("ignore")
-
-    click.echo("Creating full text archive"+click.style("...",blink=True))
+    if warn or log:
+        click.echo(click.style("* ",blink=True) + "Creating full text archive...")
 
     if not from_archive:
         allpagestext = pd.Series(queue).map(lambda x: get.PDFText(x))
@@ -159,7 +158,7 @@ def archive(conf):
 
     if append:
         try:
-            new = [OLD_ARCHIVE, outputs]
+            new = [old_archive, outputs]
             outputs = pd.concat(new,ignore_index=True)
         except:
             pass
